summaryrefslogtreecommitdiff
path: root/lib/mkstemp.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/mkstemp.c')
-rw-r--r--lib/mkstemp.c33
1 files changed, 19 insertions, 14 deletions
diff --git a/lib/mkstemp.c b/lib/mkstemp.c
index 57ee228..90ed78e 100644
--- a/lib/mkstemp.c
+++ b/lib/mkstemp.c
@@ -1,19 +1,19 @@
-/* Copyright (C) 1998, 1999, 2001, 2005, 2006, 2007 Free Software Foundation, Inc.
+/* Copyright (C) 1998-1999, 2001, 2005-2007, 2009-2016 Free Software
+ Foundation, Inc.
This file is derived from the one in the GNU C Library.
- This program is free software; you can redistribute it and/or modify
+ This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
- any later version.
+ the Free Software Foundation; either version 3 of the License, or
+ (at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
- You should have received a copy of the GNU General Public License along
- with this program; if not, write to the Free Software Foundation,
- Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. */
+ You should have received a copy of the GNU General Public License
+ along with this program. If not, see <http://www.gnu.org/licenses/>. */
#if !_LIBC
# include <config.h>
@@ -24,7 +24,9 @@
#if !_LIBC
# include "tempname.h"
# define __gen_tempname gen_tempname
-# define __GT_FILE GT_FILE
+# ifndef __GT_FILE
+# define __GT_FILE GT_FILE
+# endif
#endif
#include <stdio.h>
@@ -33,13 +35,16 @@
# define __GT_FILE 0
#endif
-/* Generate a unique temporary file name from TEMPLATE.
- The last six characters of TEMPLATE must be "XXXXXX";
+/* Generate a unique temporary file name from XTEMPLATE.
+ The last six characters of XTEMPLATE must be "XXXXXX";
they are replaced with a string that makes the file name unique.
- Then open the file and return a fd. */
+ Then open the file and return a fd.
+
+ If you are creating temporary files which will later be removed,
+ consider using the clean-temp module, which avoids several pitfalls
+ of using mkstemp directly. */
int
-mkstemp (template)
- char *template;
+mkstemp (char *xtemplate)
{
- return __gen_tempname (template, __GT_FILE);
+ return __gen_tempname (xtemplate, 0, 0, __GT_FILE);
}